==> social-8.x-1.0-rc4-no-core.tar.gz: social/modules/contrib/votingapi/src/VoteTypeListBuilder.php <==
<?php

/**
 * @file
 * Contains \Drupal\votingapi\VoteTypeListBuilder.
 */

namespace Drupal\votingapi;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Url;
use Drupal\Core\Entity\EntityInterface;

/**
 * Defines a class to build a listing of vote type entities.
 *
 * @see \Drupal\votingapi\Entity\VoteType
 */
class VoteTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = t('Id');
    $header['label'] = t('Label');
    $header['value_type'] = t('Value type');
    $header['description'] = array(
      'data' => t('Description'),
      'class' => array(RESPONSIVE_PRIORITY_MEDIUM),
    );
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id']['data'] = ['#markup' => $entity->id()];
    $row['label'] = array(
      'data' => $entity->label(),
      'class' => array('menu-label'),
    );
    $row['value_type']['data'] = ['#markup' => $entity->getValueType()];
    $row['description']['data'] = ['#markup' => $entity->getDescription()];
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);
    // Place the edit operation after the operations added by field_ui.module
    // which have the weights 15, 20, 25.
    if (isset($operations['edit'])) {
      $operations['edit']['weight'] = 30;
    }
    return $operations;
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    $build['table']['#empty'] = $this->t('No vote types available. <a href="@link">Add vote type</a>.', [
      '@link' => Url::fromRoute('votingapi.type_add')->toString()
    ]);
    return $build;
  }
}

==> social-8.x-3.4-no-core.tar.gz: social/modules/contrib/votingapi/src/VoteTypeListBuilder.php <==
<?php

namespace Drupal\votingapi;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Url;
use Drupal\Core\Entity\EntityInterface;

/**
 * Defines a class to build a listing of vote type entities.
 *
 * @see \Drupal\votingapi\Entity\VoteType
 */
class VoteTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = t('Id');
    $header['label'] = t('Label');
    $header['value_type'] = t('Value type');
    $header['description'] = [
      'data' => t('Description'),
      'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['id']['data'] = ['#markup' => $entity->id()];
    $row['label'] = [
      'data' => $entity->label(),
      'class' => ['menu-label'],
    ];
    $row['value_type']['data'] = ['#markup' => $entity->getValueType()];
    $row['description']['data'] = ['#markup' => $entity->getDescription()];
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);
    // Place the edit operation after the operations added by field_ui.module
    // which have the weights 15, 20, 25.
    if (isset($operations['edit'])) {
      $operations['edit']['weight'] = 30;
    }
    return $operations;
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    $build['table']['#empty'] = $this->t('No vote types available. <a href="@link">Add vote type</a>.', [
      '@link' => Url::fromRoute('votingapi.type_add')->toString(),
    ]);
    return $build;
  }
}
